<?php
/**
 * Outputs the customizer styles.
 *
 * @package e-shopper
 * @since 3.0.0
 */

/**
 * Outputs the custom styles for the theme.
 *
 * @return void
 */
function e_shopper_custom_color_styles() {
	$accent_color     = get_theme_mod( 'e_shopper_colors_accent', '#ac988e' );
	$alt_accent_color = get_theme_mod( 'e_shopper_colors_alt_accent', '#171717' );

	$page_header_text_color = e_shopper_get_contrast_text_color( '#' . get_background_color(), '#ffffff' );

	$custom_css = "
		a {
			border-bottom-color: {$accent_color};
			color: {$accent_color};
		}

		a:hover,
		.page-header .woocommerce-breadcrumb a:hover,
		.page-header .woocommerce-breadcrumb h1:hover {
			border-bottom-color: {$alt_accent_color};
			color: {$alt_accent_color};
		}

		.woocommerce-cart .content-area .woocommerce-cart-form table td input.button,
		.woocommerce #respond input#submit,
		.woocommerce-page ul.products li.product .button,
		.woocommerce ul.products li.product .button,
		.woocommerce nav.woocommerce-pagination ul.page-numbers li .page-numbers:hover,
		.woocommerce nav.woocommerce-pagination ul.page-numbers li .page-numbers:focus,
		.woocommerce nav.woocommerce-pagination ul.page-numbers li .page-numbers.current,
		.woocommerce-error, .woocommerce-info, .woocommerce-message,
		.woocommerce span.onsale,
		.woocommerce-page .widget_price_filter .ui-slider .ui-slider-handle,
		.woocommerce-page .widget_price_filter .ui-slider .ui-slider-range,
		.woocommerce .widget_price_filter .ui-slider .ui-slider-handle,
		.woocommerce .widget_price_filter .ui-slider .ui-slider-range,
		.site-content .page-header .woocommerce-breadcrumb,
		.site-content .page-header .woocommerce-products-header,
		.woocommerce-cart .content-area .wc-proceed-to-checkout a.checkout-button.button.alt.wc-forward:hover,
		.site-content .woocommerce .button.alt,
		.site-content .woocommerce .button,
		.woocommerce .button.alt.button, .woocommerce .button.button,
		.site-content .product .button.alt,
		.site-content .products .button,
		.btn,
		button,
		input[type=submit],
		input[type=button],
		.main-navigation .menu li.call-to-action a {
			background-color: {$accent_color};
			border-color: {$accent_color};
		}

		.woocommerce #respond input#submit:hover,
		.woocommerce-page ul.products li.product .button:hover,
		.woocommerce ul.products li.product .button:hover,
		.woocommerce-cart .content-area .wc-proceed-to-checkout a.checkout-button.button.alt.wc-forward,
		.woocommerce .button.alt.button:hover,
		.woocommerce .button.button:hover,
		.site-content .woocommerce .button.alt:hover,
		.site-content .woocommerce .button:hover,
		.site-content .product .button.alt:hover,
		.site-content .products .button:hover,
		.btn:hover,
		button:hover,
		input[type=submit]:hover,
		input[type=button]:hover,
		.main-navigation .menu li.call-to-action a:hover {
			background-color: {$alt_accent_color};
			border-color: {$alt_accent_color};
		}

		.woocommerce-checkout .content-area .woocommerce-checkout table tfoot td:last-child,
		.woocommerce ul.products li.product .price,
		.site-header a:hover,
		.hentry .entry-header a:hover,
		.hentry .entry-meta a:hover,
		.widget-area.sidebar .widget a:hover {
			color: {$accent_color};
		}

		.site-header-business .main-navigation,
		.site-header-blog .main-navigation {
			background-color: {$accent_color};
		}

		.bypostauthor .comment-meta .avatar{
	   		border-color: {$accent_color};
	   	}

		.site-content .page-header,
		.site-content .page-template-elementor .entry-header {
			color: {$page_header_text_color};
			background-color: {$accent_color};
		}

		@media ( min-width: 992px ) {
			.site-header-business .main-navigation .sub-menu a:hover,
			.site-header-blog .main-navigation .sub-menu a:hover {
				color: {$accent_color};
			}
		}
	";

	wp_add_inline_style( 'e-shopper-style', $custom_css );
}
add_action( 'wp_enqueue_scripts', 'e_shopper_custom_color_styles', 100 );

/**
 * Outputs the custom styles for the theme.
 *
 * @return void
 */
function e_shopper_custom_typography_styles() {
	$fonts        = e_shopper_get_selected_fonts();
	$body_font    = $fonts['body'];
	$heading_font = $fonts['heading'];

	$custom_css = "
		.woocommerce-page ul.products li.product .woocommerce-loop-product__title,
		.woocommerce ul.products li.product .woocommerce-loop-product__title,
		.btn,
		input[type=submit],
		input[type=button],
		button,
		body,
		input,
		select,
		.main-navigation,
		textarea {
			font-family: '{$body_font}', serif;
		}

		.h1, h1,
		.h2, h2,
		.h3, h3,
		.h4, h4,
		.h5, h5,
		.h6, h6,
		.hentry .more-link,
		.comment-meta .fn,
		.site-footer {
			font-family: '{$heading_font}', serif;
		}
	";

	wp_add_inline_style( 'e-shopper-style', $custom_css );
}
add_action( 'wp_enqueue_scripts', 'e_shopper_custom_typography_styles', 100 );


/**
 * Outputs the custom styles for home page.
 *
 * @return void
 */
function e_shopper_custom_homepage_styles() {
	$hero_overlay_color   = get_theme_mod( 'e_shopper_home_hero_area_overlay_color', '#000000' );
	$hero_overlay_opacity = get_theme_mod( 'e_shopper_home_hero_area_overlay_opacity', '0.6' );
	$hero_text_color      = e_shopper_get_contrast_text_color( $hero_overlay_color, '#222222' );
	$hero_bg_image        = wp_get_attachment_image_src( get_theme_mod( 'e_shopper_home_hero_area_bg_image' ), 'full' );

	$custom_css = "
		.page-template-homepage-premium .home-section.hero {
			background-image: url({$hero_bg_image[0]});
			color: $hero_text_color;
		}
		.page-template-homepage-premium .home-section.hero:before {
			background-color: {$hero_overlay_color};
			opacity: {$hero_overlay_opacity};
		}
	";

	$recent_products_overlay_color   = get_theme_mod( 'e_shopper_home_recent_posts_overlay_color', '#eaeaea' );
	$recent_products_overlay_opacity = get_theme_mod( 'e_shopper_home_recent_posts_overlay_opacity', '1' );
	$recent_products_text_color      = e_shopper_get_contrast_text_color( $recent_products_overlay_color, '#222222' );
	$recent_products_bg_image        = wp_get_attachment_image_src( get_theme_mod( 'e_shopper_home_recent_posts_bg_image' ), 'full' );

	$custom_css .= "
		.page-template-homepage-premium .home-section.recent-products {
			background-image: url({$recent_products_bg_image[0]});
			color: $recent_products_text_color;
		}
		.page-template-homepage-premium .home-section.recent-products:before {
			background-color: {$recent_products_overlay_color};
			opacity: {$recent_products_overlay_opacity};
		}
	";

	wp_add_inline_style( 'e-shopper-style', $custom_css );
}
add_action( 'wp_enqueue_scripts', 'e_shopper_custom_homepage_styles', 100 );

/**
 * Adds custom classes to body for header/content layout.
 *
 * @param  array $classes The default body classes.
 * @return array          Body classes with custom classes added.
 */
function e_shopper_custom_body_class( $classes ) {
	$full_width_header = get_theme_mod( 'e_shopper_full_width_header', false );
	if ( $full_width_header ) {
		$classes[] = 'full-width-header';
	}

	$sidebar_layout = get_theme_mod( 'e_shopper_sidebar_layout', 'default' );
	if ( 'default' !== $sidebar_layout ) {
		$classes[] = 'sidebar-layout-' . $sidebar_layout;
	}

	return $classes;
}
add_filter( 'body_class', 'e_shopper_custom_body_class' );
