<?php
/**
 * Theme color options.
 *
 * @package e-shopper
 * @since 3.0.0
 */

/**
 * Registers the customizer color options.
 *
 * @param  WP_Customize_Manager $wp_customize The WordPress customizer manager instance.
 * @return void
 */
function e_shopper_customize_register_colors( $wp_customize ) {
	$colors = e_shopper_get_colors();

	foreach ( $colors as $color => $args ) {
		$wp_customize->add_setting(
			$color,
			array(
				'default'           => $args['default'],
				'sanitize_callback' => 'sanitize_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				$color,
				array(
					'active_callback' => array_key_exists( 'active_callback', $args ) ? $args['active_callback'] : '',
					'label'           => $args['label'],
					'section'         => 'colors',
				)
			)
		);
	}

	/**
	 * Changes the background color protocol to show page-header text
	 * color changes.
	 */
	$wp_customize->get_setting( 'background_color' )->transport = 'refresh';
}
add_action( 'customize_register', 'e_shopper_customize_register_colors' );

/**
 * Returns the theme color options.
 *
 * @return array
 */
function e_shopper_get_colors() {
	$colors = array(
		'e_shopper_colors_accent'     => array(
			'label'   => esc_html__( 'Accent Color', 'e-shopper' ),
			'default' => '#ac988e',
		),
		'e_shopper_colors_alt_accent' => array(
			'label'   => esc_html__( 'Alternate Accent Color', 'e-shopper' ),
			'default' => '#171717',
		),
	);

	return apply_filters( 'e_shopper_colors', $colors );
}
