<?php
/**
 * Theme homepage options.
 *
 * @package e-shopper
 * @since 3.0.0
 */

/**
 * Registers the customizer homepage options.
 *
 * @param  WP_Customize_Manager $wp_customize The WordPress customizer manager instance.
 * @return void
 */
function e_shopper_customize_register_homepage( $wp_customize ) {
	/**
	 * == Homepage ==
	 *
	 * Add a homepage settings panel.
	 */
	$wp_customize->add_panel(
		'e_shopper_home',
		array(
			'priority' => 120,
			'title'    => esc_html__( 'Homepage', 'e-shopper' ),
		)
	);

	/**
	 * Move the homepage settings section to the homepage settings panel.
	 */
	$static_front_page_section        = $wp_customize->get_section( 'static_front_page' );
	$static_front_page_section->panel = 'e_shopper_home';
	$static_front_page_section->title = esc_html__( 'Settings', 'e-shopper' );

	/**
	 * == Recent Products ==
	 *
	 * Add fields in recent products section.
	 * Add option to set the overlay color.
	 *
	 * Add recent products section.
	 */
	$wp_customize->add_section(
		'e_shopper_home_recent_posts',
		array(
			'active_callback' => 'e_shopper_is_homepage',
			'panel'           => 'e_shopper_home',
			'title'           => esc_html__( 'Recent Products', 'e-shopper' ),
			'priority'        => 1004,
		)
	);

	/**
	 * Add option to enable/disable recent products.
	 */
	$wp_customize->add_setting(
		'e_shopper_home_show_recent_posts',
		array(
			'default'           => true,
			'sanitize_callback' => 'e_shopper_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'e_shopper_home_show_recent_posts',
			array(
				'label'   => esc_html__( 'Show recent products?', 'e-shopper' ),
				'section' => 'e_shopper_home_recent_posts',
				'type'    => 'checkbox',
			)
		)
	);

	/**
	 * Add option to set the title of recent products section.
	 */
	$wp_customize->add_setting(
		'e_shopper_home_recent_posts_title',
		array(
			'default'           => esc_html__( 'Recent Products', 'e-shopper' ),
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'e_shopper_home_recent_posts_title',
			array(
				'label'   => esc_html__( 'Title', 'e-shopper' ),
				'section' => 'e_shopper_home_recent_posts',
				'type'    => 'text',
			)
		)
	);

	/**
	 * Add option to set the description of recent products section.
	 */
	$wp_customize->add_setting(
		'e_shopper_home_recent_posts_description',
		array(
			'default'           => '',
			'sanitize_callback' => 'wp_kses_post',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'e_shopper_home_recent_posts_description',
			array(
				'label'   => esc_html__( 'Description', 'e-shopper' ),
				'section' => 'e_shopper_home_recent_posts',
				'type'    => 'textarea',
			)
		)
	);

	/**
	 * Add option to upload background image
	 */
	$wp_customize->add_setting(
		'e_shopper_home_recent_posts_bg_image',
		array(
			'sanitize_callback' => 'absint',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Cropped_Image_Control(
			$wp_customize,
			'e_shopper_home_recent_posts_bg_image',
			array(
				'label'       => esc_html__( 'Background image', 'e-shopper' ),
				'description' => esc_html__( 'Increase or decrease background image visibility by changing the Overlay Opacity.', 'e-shopper' ),
				'section'     => 'e_shopper_home_recent_posts',
				'flex-height' => true,
				'flex-width'  => true,
				'height'      => 1000, // pixels.
				'width'       => 1500, // pixels.
			)
		)
	);

	$wp_customize->add_setting(
		'e_shopper_home_recent_posts_overlay_color',
		array(
			'default'           => '#eaeaea',
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'e_shopper_home_recent_posts_overlay_color',
			array(
				'label'    => esc_html__( 'Overlay Color', 'e-shopper' ),
				'section'  => 'e_shopper_home_recent_posts',
				'settings' => 'e_shopper_home_recent_posts_overlay_color',
			)
		)
	);

	/**
	* Add option to set the opacity.
	*/
	$wp_customize->add_setting(
		'e_shopper_home_recent_posts_overlay_opacity',
		array(
			'default'           => 1,
			'sanitize_callback' => 'e_shopper_sanitize_opacity',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'e_shopper_home_recent_posts_overlay_opacity',
			array(
				'label'       => esc_html__( 'Overlay Opacity', 'e-shopper' ),
				'section'     => 'e_shopper_home_recent_posts',
				'type'        => 'range',
				'input_attrs' => array(
					'min'  => '0.1',
					'max'  => '1',
					'step' => '0.1',
				),
			)
		)
	);

	/**
	* Add option to set Number of Product on homepage recent product section.
	*/
	$wp_customize->add_setting(
		'e_shopper_products_no_of_products_homepage',
		array(
			'default'           => 3,
			'sanitize_callback' => 'absint',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'e_shopper_products_no_of_products_homepage',
			array(
				'label'       => esc_html__( 'Products Per Page', 'e-shopper' ),
				'section'     => 'e_shopper_home_recent_posts',
				'type'        => 'range',
				'input_attrs' => array(
					'min'  => '2',
					'max'  => '8',
					'step' => '1',
				),
			)
		)
	);

	/**
	* Add option to set Product per Row on shop.
	*/
	$wp_customize->add_setting(
		'e_shopper_products_per_row_on_homepage',
		array(
			'default'           => 3,
			'sanitize_callback' => 'absint',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'e_shopper_products_per_row_on_homepage',
			array(
				'label'       => esc_html__( 'Products Per Row', 'e-shopper' ),
				'section'     => 'e_shopper_home_recent_posts',
				'type'        => 'range',
				'input_attrs' => array(
					'min'  => '1',
					'max'  => '4',
					'step' => '1',
				),
			)
		)
	);
}
add_action( 'customize_register', 'e_shopper_customize_register_homepage' );

/**
 * Checks if the current page is:
 * - the front page
 * - and has the free or premium homepage template.
 *
 * @return boolean true if the above criteria are met, otherwise false.
 */
function e_shopper_is_homepage() {
	return is_front_page() && is_page_template( 'templates/homepage-premium.php' );
}

/**
 * Checks if the current page is:
 * - the front page
 * - has the free or premium homepage template
 * - citations sidebar is active
 *
 * @return boolean true if the above criteria are met, otherwise false.
 */
function e_shopper_show_homepage_citations() {
	return e_shopper_is_homepage() && is_active_sidebar( 'citations' );
}

/**
 * Sanitizes the overlay opacity.
 *
 * @param int $value to return.
 * @return float The sanitized base line height.
 */
function e_shopper_sanitize_opacity( $value ) {
	if ( ! abs( floatval( $value ) ) ) {
		$value = '0';
	}

	return $value;
}
