<?php
/**
 * Theme shop options.
 *
 * @package e-shopper
 * @since 3.0.0
 */

/**
 * Registers the customizer shop options.
 *
 * @param  WP_Customize_Manager $wp_customize The WordPress customizer manager instance.
 * @return void
 */
function e_shopper_customize_register_shop( $wp_customize ) {
	/**
	 * == Shop Section ==
	 *
	 * Adds the shop section.
	 */
	$wp_customize->add_section(
		'e_shopper_shop',
		array(
			'title'    => esc_html__( 'Shop', 'e-shopper' ),
			'priority' => 35,
		)
	);

	/**
	* Add option to set Product per page on shop.
	*/
	$wp_customize->add_setting(
		'e_shopper_products_per_page',
		array(
			'default'           => 12,
			'sanitize_callback' => 'absint',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'e_shopper_products_per_page',
			array(
				'label'       => esc_html__( 'Products Per Page', 'e-shopper' ),
				'section'     => 'e_shopper_shop',
				'type'        => 'range',
				'input_attrs' => array(
					'min'  => '3',
					'max'  => '16',
					'step' => '1',
				),
			)
		)
	);

	/**
	* Add option to set Product per Row on shop.
	*/
	$wp_customize->add_setting(
		'e_shopper_products_per_row',
		array(
			'default'           => 3,
			'sanitize_callback' => 'absint',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'e_shopper_products_per_row',
			array(
				'label'       => esc_html__( 'Products Per Row', 'e-shopper' ),
				'section'     => 'e_shopper_shop',
				'type'        => 'range',
				'input_attrs' => array(
					'min'  => '1',
					'max'  => '4',
					'step' => '1',
				),
			)
		)
	);
}
add_action( 'customize_register', 'e_shopper_customize_register_shop' );
