<?php
/**
 * E-shopper minicart functions and definitions
 *
 * Ensure cart contents update when products are added to the cart via AJAX.
 *
 * @package e-shopper
 */

if ( ! function_exists( 'e_shopper_woocommerce_cart_link_fragment' ) ) {
	/**
	 * Cart Fragments.
	 *
	 * Ensure cart contents update when products are added to the cart via AJAX.
	 *
	 * @param array $fragments Fragments to refresh via AJAX.
	 * @return array Fragments to refresh via AJAX.
	 */
	function e_shopper_woocommerce_cart_link_fragment( $fragments ) {
		ob_start();
		e_shopper_woocommerce_cart_link();
		$fragments['a.cart-contents'] = ob_get_clean();

		return $fragments;
	}
}
add_filter( 'woocommerce_add_to_cart_fragments', 'e_shopper_woocommerce_cart_link_fragment' );

if ( ! function_exists( 'e_shopper_woocommerce_cart_link' ) ) {
	/**
	 * Cart Link.
	 *
	 * Displayed a link to the cart including the number of items present and the cart total.
	 *
	 * @return void
	 */
	function e_shopper_woocommerce_cart_link() {
		?>
		<a id="basket-icon" class="cart-contents icon-basket" href="#e-shopper-cart-content" title="<?php esc_html_e( 'View your shopping cart', 'e-shopper' ); ?>">
			<?php
			$count = WC()->cart->cart_contents_count;
			if ( $count > 0 ) {
				?>
			<span class="cart-contents-count"><?php echo esc_html( $count ); ?></span>
				<?php
			}
			?>
		</a>
		<?php
	}
}

if ( ! function_exists( 'e_shopper_woocommerce_header_cart' ) ) {
	/**
	 * Display Header Cart.
	 *
	 * @return void
	 */
	function e_shopper_woocommerce_header_cart() {
		if ( is_cart() ) {
			$class = 'current-menu-item';
		} else {
			$class = '';
		}
		$instance = array(
			'title' => '',
		);

		the_widget( 'WC_Widget_Cart', $instance );
	}
}
