<?php
/**
 * WooCommerce Compatibility File
 *
 * @link https://woocommerce.com/
 *
 * @package e-Shopper
 */

/**
 * WooCommerce setup function.
 *
 * @link https://docs.woocommerce.com/document/third-party-custom-theme-compatibility/
 * @link https://github.com/woocommerce/woocommerce/wiki/Enabling-product-gallery-features-(zoom,-swipe,-lightbox)-in-3.0.0
 *
 * @return void
 */
function e_shopper_woocommerce_setup() {
	add_theme_support( 'woocommerce' );
	add_theme_support( 'wc-product-gallery-zoom' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );
}
add_action( 'after_setup_theme', 'e_shopper_woocommerce_setup' );

/**
 * [e_shopper_is_woocommerce_active description].
 *
 * @return boolean [description]
 */
function e_shopper_is_woocommerce_active() {
	return in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) );
}

/**
 * Products per page.
 *
 * @return integer number of products.
 */
function e_shopper_woocommerce_products_per_page() {
	$e_shopper_products_per_page = get_theme_mod( 'e_shopper_products_per_page', 12 );

	return $e_shopper_products_per_page;
}
add_filter( 'loop_shop_per_page', 'e_shopper_woocommerce_products_per_page' );

/**
 * Product gallery thumnbail columns.
 *
 * @return integer number of columns.
 */
function e_shopper_woocommerce_thumbnail_columns() {

	return 4;
}
add_filter( 'woocommerce_product_thumbnails_columns', 'e_shopper_woocommerce_thumbnail_columns' );

/**
 * Default loop columns on product archives.
 *
 * @return integer products per row.
 */
function e_shopper_woocommerce_loop_columns() {
	$e_shopper_products_per_row = get_theme_mod( 'e_shopper_products_per_row', 3 );

	return $e_shopper_products_per_row;
}
add_filter( 'loop_shop_columns', 'e_shopper_woocommerce_loop_columns' );


/**
 * Related Products Args.
 *
 * @param array $args related products args.
 * @return array $args related products args.
 */
function e_shopper_woocommerce_related_products_args( $args ) {
	$defaults = array(
		'posts_per_page' => 4,
		'columns'        => 4,
	);

	$args = wp_parse_args( $defaults, $args );

	return $args;
}
add_filter( 'woocommerce_output_related_products_args', 'e_shopper_woocommerce_related_products_args' );


// Remove cross-sells at cart.
remove_action( 'woocommerce_cart_collaterals', 'woocommerce_cross_sell_display' );


if ( ! function_exists( 'e_shopper_woocommerce_before_single_product_summary' ) ) {
	/**
	 * Single Product columns wrapper.
	 *
	 * @return  void
	 */
	function e_shopper_woocommerce_before_single_product_summary() {
		?>
	</div>
	</div>
	</div>
	</header>
		<div class="container">
			<div class="row">
				<main id="primary" class="content-area col-xs-12 col-lg-12" role="main">
		<?php
	}
}
add_action( 'woocommerce_before_single_product', 'e_shopper_woocommerce_before_single_product_summary', 5 );


if ( ! function_exists( 'e_shopper_woocommerce_after_single_product_summary' ) ) {
	/**
	 * Single Product columns wrapper.
	 *
	 * @return  void
	 */
	function e_shopper_woocommerce_after_single_product_summary() {
		?>
		</div>
		</div>
		</div>
		<?php
	}
}
add_action( 'woocommerce_after_single_product', 'e_shopper_woocommerce_after_single_product_summary', 5 );

if ( ! function_exists( 'e_shopper_woocommerce_product_columns_wrapper_open' ) ) {
	/**
	 * Product columns wrapper close.
	 *
	 * @return  void
	 */
	function e_shopper_woocommerce_product_columns_wrapper_open() {
		$e_shopper_products_per_row = get_theme_mod( 'e_shopper_products_per_row', 3 );

		echo '<div class="columns-' . esc_html( $e_shopper_products_per_row ) . '">';
	}
}
add_action( 'woocommerce_before_shop_loop', 'e_shopper_woocommerce_product_columns_wrapper_open', 40 );

if ( ! function_exists( 'e_shopper_woocommerce_product_columns_wrapper_close' ) ) {
	/**
	 * Product columns wrapper close.
	 *
	 * @return  void
	 */
	function e_shopper_woocommerce_product_columns_wrapper_close() {
		echo '</div></main>';
	}
}
add_action( 'woocommerce_after_shop_loop', 'e_shopper_woocommerce_product_columns_wrapper_close', 40 );


/**
 * Remove default WooCommerce wrapper.
 */
remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10 );
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10 );

if ( ! function_exists( 'e_shopper_woocommerce_wrapper_before' ) ) {
	/**
	 * Before Content.
	 *
	 * Wraps all WooCommerce content in wrappers which match the theme markup.
	 *
	 * @return void
	 */
	function e_shopper_woocommerce_wrapper_before() {
		?>
		<div id="content" class="site-content">
			<header class="page-header">
				<div class="container">
			<?php
	}
}
add_action( 'woocommerce_before_main_content', 'e_shopper_woocommerce_wrapper_before' );

if ( ! function_exists( 'e_shopper_woocommerce_wrapper_after' ) ) {
	/**
	 * After Content.
	 *
	 * Closes the wrapping divs.
	 *
	 * @return void
	 */
	function e_shopper_woocommerce_wrapper_after() {
		if ( is_search() && ! have_posts() ) {
			get_template_part( 'template-parts/content/entry', 'none' );
			echo '</div></main></div>';
		}
		get_sidebar();
		echo '</div></div></div>';
	}
}
add_action( 'woocommerce_after_main_content', 'e_shopper_woocommerce_wrapper_after' );



if ( ! function_exists( 'e_shopper_woocommerce_archive_description' ) ) {
	/**
	 * Cart page wrapper.
	 *
	 * @return  void
	 */
	function e_shopper_woocommerce_archive_description() {
		?>
	</div>
	</header>
		<div class="container">
			<div class="row">
				<main id="primary" class="content-area col-xs-12 col-md-8 col-lg-8" role="main">
					<div class="columns_page">
						<?php

	}
}
add_action( 'woocommerce_archive_description', 'e_shopper_woocommerce_archive_description', 10 );


if ( ! function_exists( 'e_shopper_woocommerce_before_shop_loop_item_title' ) ) {
	/**
	 * Cart page wrapper.
	 *
	 * @return  void
	 */
	function e_shopper_woocommerce_before_shop_loop_item_title() {
		echo '<div class="recent_detail">';
	}
}
add_action( 'woocommerce_before_shop_loop_item_title', 'e_shopper_woocommerce_before_shop_loop_item_title', 15 );



if ( ! function_exists( 'e_shopper_woocommerce_after_shop_loop_item' ) ) {
	/**
	 * Cart page wrapper.
	 *
	 * @return  void
	 */
	function e_shopper_woocommerce_after_shop_loop_item() {
		echo '</div>';
	}
}
add_action( 'woocommerce_after_shop_loop_item', 'e_shopper_woocommerce_after_shop_loop_item', 15 );

/* Remove product meta */
remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_meta', 40 );
